pub enum WriteCaPemError {
SystemClock(SystemTimeError),
Write(Error),
}Expand description
Failure modes of [write_ca_pem_to_temp].
Variants
SystemClock(SystemTimeError)
The system clock reports a time before the Unix epoch, so the unique temp-file suffix cannot be derived.
Write(Error)
The CA certificate PEM could not be written to the temp file.