Command

Enum Command 

pub enum Command {
    Cache {
        instance_name: InstanceName,
        command: CacheCommand,
    },
    ContainerPsql {
        instance_name: InstanceName,
    },
    List,
    ContainerSchemaDump {
        instance_name: InstanceName,
    },
    ContainerShell {
        instance_name: InstanceName,
    },
    IntegrationServer {
        instance_name: InstanceName,
        result_fd: RawFd,
        control_fd: RawFd,
    },
    Psql {
        instance_name: InstanceName,
    },
    RunEnv {
        instance_name: InstanceName,
        command: String,
        arguments: Vec<String>,
    },
    Platform {
        command: PlatformCommand,
    },
}

Variants



Cache

Cache related commands

Fields

instance_name: InstanceName

Target instance name



ContainerPsql

Run interactive psql session on the container

Fields

instance_name: InstanceName

Target instance name



List

List defined instances



ContainerSchemaDump

Run schema dump from the container

Fields

instance_name: InstanceName

Target instance name



ContainerShell

Run interactive shell on the container

Fields

instance_name: InstanceName

Target instance name



IntegrationServer

Run integration server

Intent to be used for automation with other languages wrapping pg-ephemeral.

After successful boot connects to the inherited pipe file descriptors, writes a single JSON line with connection details to –result-fd, then waits for EOF on –control-fd before shutting down.

Fields

instance_name: InstanceName

Target instance name

result_fd: RawFd

File descriptor for writing the result JSON

control_fd: RawFd

File descriptor for reading the control signal (EOF = shutdown)



Psql

Run interactive psql on the host

Fields

instance_name: InstanceName

Target instance name



RunEnv

Run shell command with environment variables for PostgreSQL connection

Sets all PostgreSQL-related environment variables:

  • libpq-style PG* environment variables (PGHOST, PGPORT, PGUSER, PGDATABASE, PGPASSWORD, PGSSLMODE, etc.)
  • DATABASE_URL in PostgreSQL URL format

Fields

instance_name: InstanceName

Target instance name

command: String

The command to run

arguments: Vec<String>

Arguments to pass to the command



Platform

Platform related commands

Fields

Implementations

Source

impl Command

pub async fn run(&self, instance_map: &InstanceMap) -> Result<(), Error>