pub enum PlatformCommand {
Support,
TestBacktrace,
}Variants
Support
Check if the current platform is supported
Exits with status 0 if platform is supported. Exits with status 1 if platform is not supported.
TestBacktrace
Trigger a panic to test backtrace quality
Used by integration tests to verify that backtraces contain file paths and line numbers in release builds.