pub enum Image {
OfficialRelease {
major: Major,
minor: Minor,
os: OS,
digest: Option<Digest>,
},
OfficialReleaseCandidate {
major: Major,
number: ReleaseCandidateNumber,
os: OS,
digest: Option<Digest>,
},
OfficialLatest {
os: OS,
digest: Option<Digest>,
},
Explicit(Reference),
}Expand description
Postgresql images supported, references images from https://hub.docker.com/_/postgres
Variants
OfficialRelease
Official release
OfficialReleaseCandidate
OfficialRelease candidate
OfficialLatest
Latest image on docker.com
Only use that one for quick and dirty testing, it’s recommended to always pin
specific images in config files. Also note that pg-ephemeral currently never refreshes
latest once cached in the local registry it’s never refreshed.
Explicit(Reference)
Explicit OCI image reference, bypassing the official postgres image naming